@@ -33,10 +33,6 @@ def get_missing_pdf_libs():
     missing = ""
     if not xml2rfc.HAVE_WEASYPRINT:
         missing += "\nCould not import weasyprint"
-    if not xml2rfc.HAVE_PYCAIRO:
-        missing += "\nCould not import pycairo"
-    if not xml2rfc.HAVE_CAIRO:
-        missing += "\nCould not find the cairo lib"
     if not xml2rfc.HAVE_PANGO:
         missing += "\nCould not find the pango lib"
     return missing
@@ -82,31 +78,16 @@ def print_country_help(options, parser):
 def get_pdf_help(missing_libs=""):
     pdf_requirements_info = """
     In order to generate PDFs, xml2rfc uses the WeasyPrint library, which
-    depends on external libaries that must be installed as native packages.
+    depends on external libraries that must be installed as native packages.
 
-    1. First, install the Cairo, Pango, and GDK-PixBuf library files on your
+    1. First, install the Pango, and other required libraries on your
     system.  See installation instructions on the WeasyPrint Docs:
     
-        https://weasyprint.readthedocs.io/en/stable/install.html
+        https://doc.courtbouillon.org/weasyprint/stable/first_steps.html
 
-    (Python 3 is not needed if your system Python is 2.7, though).
+    2. Next, install weasyprint python modules using pip.
 
-
-    2. Next, install the pycairo and weasyprint python modules using pip.
-    Depending on your system, you may need to use 'sudo' or install in
-    user-specific directories, using the --user switch.  On OS X in
-    particular, you may also need to install a newer version of setuptools
-    using --user before weasyprint can be installed.  If you install with 
-    the --user switch, you may need to also set PYTHONPATH, e.g.,
-    
-        PYTHONPATH=/Users/username/Library/Python/2.7/lib/python/site-packages
-
-    for Python 2.7.
-
-    The basic pip commands (modify as needed according to the text above)
-    are:
-
-        pip install 'pycairo>=1.18' 'weasyprint<=0.42.3'
+        pip install 'weasyprint>=53.0'
 
 
     3. Finally, install the full Noto Font and Roboto Mono packages:
@@ -212,7 +193,7 @@ def main():
                            help='outputs formatted HTML to file')
     formatgroup.add_argument('--nroff', action='store_true',
                            help='outputs formatted nroff to file (only v2 input)')
-    if xml2rfc.HAVE_CAIRO and xml2rfc.HAVE_PANGO:
+    if xml2rfc.HAVE_PANGO:
         formatgroup.add_argument('--pdf', action='store_true',
                                help='outputs formatted PDF to file')
     else:
@@ -242,7 +223,7 @@ def main():
     plain_options.add_argument('-N', '--no-network', action='store_true', default=False,
                             help='don\'t use the network to resolve references')
     plain_options.add_argument('-O', '--no-org-info', dest='first_page_author_org', action='store_false', default=True,
-                            help='don\'t show author orgainzation info on page one (legacy only)')
+                            help='don\'t show author organization info on page one (legacy only)')
     plain_options.add_argument('-q', '--quiet', action='store_true',
                             help="don't print anything while working")
     plain_options.add_argument('--skip-config-files', action="store_true", default=False,
@@ -334,6 +315,8 @@ def main():
                            help=configargparse.SUPPRESS),
     htmloptions.add_argument('--no-inline-version-info', action='store_false', dest="inline_version_info",
                            help=configargparse.SUPPRESS),
+    htmloptions.add_argument('--no-rfc-local', action='store_false', dest='rfc_local', default=True,
+                             help='Do not link to rfc-local.css')
 
     v2v3options = optionparser.add_argument_group('V2-V3 Converter Options')
     v2v3options.add_argument('--add-xinclude', action='store_true',
@@ -402,7 +385,7 @@ def main():
         sys.exit()
 
     # --- Parse and validate arguments ---------------------------------
-    # tempates_dir
+    # template_dir
     options.template_dir = options.template_dir or default_options.template_dir
 
     if (options.docfile or options.manpage) and not options.list_symbols:
@@ -561,7 +544,7 @@ def main():
         options.vocabulary = 'v3'
 
     # ------------------------------------------------------------------
-    # Additional option checks that depend on the option.legacy settin which
+    # Additional option checks that depend on the option.legacy setting which
     # we may have adjusted as a result of the <rfc version="..."> setting:
     if options.text and not options.legacy:
         if options.legacy_list_symbols and options.list_symbols:
