@@ -29,7 +29,7 @@ from xml2rfc.uniscripts import is_script
 from xml2rfc.util.date import extract_date, augment_date, format_date, get_expiry_date
 from xml2rfc.util.name import short_author_ascii_name_parts, full_author_name_expansion, short_author_name_parts
 from xml2rfc.util.unicode import ( punctuation, unicode_replacements, unicode_content_tags, bare_unicode_tags,
-    bare_latin_tags, unicode_attributes, downcode, downcode_punctuation)
+    bare_latin_tags, unicode_attributes, downcode, downcode_punctuation, is_svg)
 from xml2rfc.utils import namespaces, find_duplicate_ids, slugify
 
 
@@ -100,6 +100,7 @@ default_options.__dict__ = {
         'raw': False,
         'rfc': None,
         'rfc_base_url': 'https://www.rfc-editor.org/rfc/',
+        'rfc_local': True,
         'rfc_reference_base_url': 'https://rfc-editor.org/rfc/',
         'silence': default_silenced_messages,
         'skip_config_files': False,
@@ -1615,7 +1616,7 @@ deprecated_element_tags = set([
 ])
 
 deprecated_attributes = [
-    # element, attrbute
+    # element, attribute
     ('artwork', 'height'),
     ('artwork', 'width'),
     ('artwork', 'xml:space'),
@@ -2047,6 +2048,8 @@ class BaseV3Writer(object):
 
         """
         for e in self.tree.iter():
+            if is_svg(e):
+                continue
             if e.text:
                 if not e.tag in unicode_content_tags:
                     try:
@@ -2121,18 +2124,17 @@ class BaseV3Writer(object):
                 else:
                     if e.text and re.search(r'\n[ \t]+$', e.text):
                         e.text = re.sub(r'\n[ \t]+$', '\n'+' '*(i), e.text)
-                    
-            #
+
             for c in e:
                 indent(c, i+ind)
-            #
-            if e.tag not in all_inline_tags:# and e.tag not in ['artwork', 'sourcecode', ]:
+
+            if e.tag not in all_inline_tags:
                 if e.tail is None or e.tail.strip()=='':
                     if e.getnext() != None:
                         e.tail = '\n'+' '*i
                     else:
                         e.tail = '\n'+' '*(i-ind)
-                else:
+                elif not is_svg(e):
                     self.warn(e, 'Unexpected text content after block tag: <%s>%s' % (e.tag, e.tail))
             else:
                 if e.tail != None and e.tail.strip()=='' and '\n' in e.tail:
@@ -2214,7 +2216,7 @@ class BaseV3Writer(object):
     def validate_after(self, e, p):
         # XXX: There is an issue with exponential increase in validation time
         # as a function of the number of attributes on the root element, on
-        # the order of minutes for the full set of possble attribute values.
+        # the order of minutes for the full set of possible attribute values.
         # See https://bugzilla.gnome.org/show_bug.cgi?id=133736 .  In our
         # schema, there is no dependency in the underlying schema on the root
         # element attributes.  In order to avoid very long validation times, we
